public class RunPattern{
    public static void main(String [] arguments){
        System.out.println("LSP creation example using the AbstractFactory pattern");
        System.out.println();
        System.out.println(" (I use the VirtualCircuit and TrafficEngineering classes when writing");
        System.out.println("  almost all of the code. This allows you to produce a very");
        System.out.println("  generic framework, and plug in Concrete Factories");
        System.out.println("  and Products to specialize the behavior of the code.");
        System.out.println("  The LSP and LSPTrafficEngineering classes provide");
        System.out.println("  the required behavior specialization in this case.)");
        System.out.println();

        System.out.println("Creating LSP and TrafficEngineering objects:");

        VirtualCircuitFactory lspFactory = new LSPFactory();
        LSP lsp = (LSP)lspFactory.createVirtualCircuit();

        lsp.setIndexValue(1);
        lsp.setInstanceIndexValue(0);
        lsp.setOrigNode("LER A-10.1.1.1");
        lsp.setTermNode("LER B-20.1.1.1");

        TrafficEngineering lspTrafficEngineering = lspFactory.createTrafficEngineering();
        lspTrafficEngineering.setRouteData("LER A(d) + LSR A(e,f) + LSR B(g,h) + LER B(i)");

        System.out.println("LSP Data:");
        System.out.println(lsp.getLSPDetails());
        System.out.println();
        System.out.println("LSP Traffic Engineering Data: (please see Figure 1 for the details)");
        System.out.println("Traffic Engineering Data is typically defined in terms of IP addresses.");
        System.out.println("We just use node and interface names for simplicity.");
        System.out.println(lspTrafficEngineering.getRouteData());
        System.out.println(lspTrafficEngineering.getTrafficEngineeringType());
        System.out.println();
        System.out.println();
    }
}